import { CommonModule } from "@angular/common";
import { Component, ElementRef, HostBinding, Input, NgModule, TemplateRef, ViewChild } from "@angular/core";
import { IgxIconModule } from "../icon";
export var Size;
(function (Size) {
    Size["SMALL"] = "small";
    Size["MEDIUM"] = "medium";
    Size["LARGE"] = "large";
})(Size || (Size = {}));
/**
 * **Ignite UI for Angular Avatar** -
 * [Documentation](https://www.infragistics.com/products/ignite-ui-angular/angular/components/avatar.html)
 *
 * The Ignite UI Avatar provides an easy way to add an avatar icon to your application.  This icon can be an
 * image, someone's initials or a material icon from the google material icon set.
 *
 * Example:
 * ```html
 * <igx-avatar initials="MS" roundShape="true" size="large">
 * </igx-avatar>
 * ```
 */
var IgxAvatarComponent = /** @class */ (function () {
    function IgxAvatarComponent(elementRef) {
        this.elementRef = elementRef;
        this.ariaLabel = "avatar";
        this.role = "img";
        this._size = "small";
        this.roundShape = false;
    }
    Object.defineProperty(IgxAvatarComponent.prototype, "classes", {
        get: function () {
            if (this.roundShape) {
                return "igx-avatar--rounded igx-avatar--" + this._size;
            }
            return "igx-avatar igx-avatar--" + this._size;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxAvatarComponent.prototype, "size", {
        get: function () {
            return this._size;
        },
        set: function (value) {
            switch (value) {
                case "small":
                case "medium":
                case "large":
                    this._size = value;
                    break;
                default:
                    this._size = "small";
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxAvatarComponent.prototype, "template", {
        get: function () {
            if (this.src) {
                return this.imageTemplate;
            }
            if (this.initials) {
                return this.initialsTemplate;
            }
            return this.iconTemplate;
        },
        enumerable: true,
        configurable: true
    });
    IgxAvatarComponent.prototype.ngOnInit = function () {
        this.roleDescription = this.getRole();
    };
    IgxAvatarComponent.prototype.getRole = function () {
        if (this.initials) {
            return "initials type avatar";
        }
        else if (this.src) {
            return "image type avatar";
        }
        else {
            return "icon type avatar";
        }
    };
    IgxAvatarComponent.decorators = [
        { type: Component, args: [{
                    selector: "igx-avatar",
                    template: "<ng-template #imageTemplate>     <img #image [src]=\"src\" class=\"igx-avatar__image\" [style.backgroundColor]=\"bgColor\" [attr.aria-roledescription]=\"roleDescription\"     /> </ng-template>  <ng-template #initialsTemplate>     <div class=\"igx-avatar__initials\" [style.backgroundColor]=\"bgColor\" [style.color]=\"color\" [attr.aria-roledescription]=\"roleDescription\">         <span>{{initials.substring(0, 2)}}</span>     </div> </ng-template>  <ng-template #iconTemplate>     <span class=\"igx-avatar__icon\" [style.backgroundColor]=\"bgColor\" [style.color]=\"color\" [attr.aria-roledescription]=\"roleDescription\">         <igx-icon [name]=\"icon\"></igx-icon>     </span> </ng-template>  <ng-container *ngTemplateOutlet=\"template\"></ng-container> <ng-content></ng-content>"
                },] },
    ];
    /** @nocollapse */
    IgxAvatarComponent.ctorParameters = function () { return [
        { type: ElementRef, },
    ]; };
    IgxAvatarComponent.propDecorators = {
        "image": [{ type: ViewChild, args: ["image",] },],
        "imageTemplate": [{ type: ViewChild, args: ["imageTemplate", { read: TemplateRef },] },],
        "initialsTemplate": [{ type: ViewChild, args: ["initialsTemplate", { read: TemplateRef },] },],
        "iconTemplate": [{ type: ViewChild, args: ["iconTemplate", { read: TemplateRef },] },],
        "ariaLabel": [{ type: HostBinding, args: ["attr.aria-label",] },],
        "role": [{ type: HostBinding, args: ["attr.role",] },],
        "classes": [{ type: HostBinding, args: ["attr.class",] },],
        "roundShape": [{ type: Input },],
        "color": [{ type: Input },],
        "bgColor": [{ type: Input },],
        "initials": [{ type: Input },],
        "icon": [{ type: Input },],
        "src": [{ type: Input },],
        "size": [{ type: Input },],
    };
    return IgxAvatarComponent;
}());
export { IgxAvatarComponent };
var IgxAvatarModule = /** @class */ (function () {
    function IgxAvatarModule() {
    }
    IgxAvatarModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [IgxAvatarComponent],
                    exports: [IgxAvatarComponent],
                    imports: [CommonModule, IgxIconModule]
                },] },
    ];
    /** @nocollapse */
    IgxAvatarModule.ctorParameters = function () { return []; };
    return IgxAvatarModule;
}());
export { IgxAvatarModule };
//# sourceMappingURL=avatar.component.js.map