import { AfterViewInit, ChangeDetectorRef, ElementRef, EventEmitter, QueryList, Renderer2 } from "@angular/core";
export declare enum ButtonGroupAlignment {
    horizontal = 0,
    vertical = 1,
}
/**
 * **Ignite UI for Angular Button Group** -
 * [Documentation](https://www.infragistics.com/products/ignite-ui-angular/angular/components/buttongroup.html)
 *
 * The Ignite UI Button Group displays a group of buttons either vertically or horizontally.  The group supports
 * single, multiple and toggle selection.
 *
 * Example:
 * ```html
 * <igx-buttongroup multiSelection="true" [values]="fontOptions">
 * </igx-buttongroup>
 * ```
 * The `fontOptions` value shown above is defined as:
 * ```typescript
 * this.fontOptions = [
 *   { icon: 'format_bold', selected: false },
 *   { icon: 'format_italic', selected: false },
 *   { icon: 'format_underlined', selected: false }];
 * ```
 */
export declare class IgxButtonGroupComponent implements AfterViewInit {
    private _el;
    private _renderer;
    buttons: QueryList<IgxButtonGroupComponent>;
    itemContentCssClass: string;
    multiSelection: boolean;
    values: any;
    disabled: boolean;
    selectedIndexes: number[];
    alignment: ButtonGroupAlignment;
    onSelect: EventEmitter<IButtonGroupEventArgs>;
    onUnselect: EventEmitter<IButtonGroupEventArgs>;
    readonly isVertical: boolean;
    private _isVertical;
    private _itemContentCssClass;
    constructor(_el: ElementRef, _renderer: Renderer2, cdr: ChangeDetectorRef);
    readonly selectedButtons: IgxButtonGroupComponent[];
    selectButton(index: number): void;
    deselectButton(index: number): void;
    ngAfterViewInit(): void;
    _clickHandler(event: any, i: any): void;
}
export interface IButtonGroupEventArgs {
    button: IgxButtonGroupComponent;
    index: number;
}
export declare class IgxButtonGroupModule {
}
