import { ElementRef, EventEmitter, OnDestroy, OnInit } from "@angular/core";
import { IgxNavigationService, IToggleView } from "../core/navigation";
/**
 * **Ignite UI for Angular Dialog Window** -
 * [Documentation](https://www.infragistics.com/products/ignite-ui-angular/angular/components/dialog.html)
 *
 * The Ignite UI Dialog Window presents a dialog window to the user which can simply display messages or display
 * more complicated visuals such as a user sign-in form.  It also provides a right and left button
 * which can be used for custom actions.
 *
 * Example:
 * ```html
 * <button (click)="form.open()">Show Dialog</button>
 * <igx-dialog #form title="Sign In" rightButtonLabel="OK">
 *   <div>
 *     <input type="text" igxInput/>
 *     <label igxLabel>Username</label>
 *   </div>
 *   <div>
 *     <input type="password" igxInput/>
 *     <label igxLabel>Password</label>
 *   </div>
 * </igx-dialog>
 * ```
 */
export declare class IgxDialogComponent implements IToggleView, OnInit, OnDestroy {
    private elementRef;
    private navService;
    private static NEXT_ID;
    private static readonly DIALOG_CLASS;
    id: string;
    title: string;
    message: string;
    leftButtonLabel: string;
    leftButtonType: string;
    leftButtonColor: string;
    leftButtonBackgroundColor: string;
    leftButtonRipple: string;
    rightButtonLabel: string;
    rightButtonType: string;
    rightButtonColor: string;
    rightButtonBackgroundColor: string;
    rightButtonRipple: string;
    closeOnOutsideSelect: boolean;
    onOpen: EventEmitter<IDialogEventArgs>;
    onClose: EventEmitter<IDialogEventArgs>;
    onLeftButtonSelect: EventEmitter<IDialogEventArgs>;
    onRightButtonSelect: EventEmitter<IDialogEventArgs>;
    readonly element: any;
    /**
     * The default `tabindex` attribute for the component
     *
     * @hidden
     */
    tabindex: number;
    private _isOpen;
    private _titleId;
    private _state;
    readonly state: string;
    readonly isOpen: boolean;
    readonly role: string;
    readonly titleId: string;
    constructor(elementRef: ElementRef, navService: IgxNavigationService);
    open(): void;
    close(): void;
    toggle(): void;
    onDialogSelected(event: any): void;
    onInternalLeftButtonSelect(event: any): void;
    onInternalRightButtonSelect(event: any): void;
    ngOnInit(): void;
    ngOnDestroy(): void;
    private toggleState(state);
}
export interface IDialogEventArgs {
    dialog: IgxDialogComponent;
    event: Event;
}
export declare class IgxDialogModule {
}
