import { DOCUMENT } from "@angular/common";
import { Directive, ElementRef, HostListener, Inject, Input, Output, TemplateRef } from "@angular/core";
import "rxjs/add/operator/map";
import "rxjs/add/operator/switchMap";
import "rxjs/add/operator/takeUntil";
import { Subject } from "rxjs/Subject";
var IgxColumnResizerDirective = /** @class */ (function () {
    function IgxColumnResizerDirective(element, document) {
        var _this = this;
        this.element = element;
        this.document = document;
        this.restrictHResizeMin = Number.MIN_SAFE_INTEGER;
        this.restrictHResizeMax = Number.MAX_SAFE_INTEGER;
        this.resizeEndTimeout = 0;
        this.resizeEnd = new Subject();
        this.resizeStart = new Subject();
        this.resize = new Subject();
        this.resizeStart.map(function (event) {
            return event.clientX;
        }).switchMap(function (offset) {
            return _this.resize.map(function (event) { return (event.clientX - offset); }).takeUntil(_this.resizeEnd);
        })
            .subscribe(function (pos) {
            var left = _this._left + pos;
            _this.left = left < _this.restrictHResizeMin ? _this.restrictHResizeMin + "px" : left + "px";
            if (left > _this.restrictHResizeMax) {
                _this.left = _this.restrictHResizeMax + "px";
            }
            else if (left > _this.restrictHResizeMin) {
                _this.left = left + "px";
            }
        });
    }
    Object.defineProperty(IgxColumnResizerDirective.prototype, "left", {
        set: function (val) {
            this.element.nativeElement.style.left = val;
        },
        enumerable: true,
        configurable: true
    });
    IgxColumnResizerDirective.prototype.onMouseup = function (event) {
        var _this = this;
        setTimeout(function () {
            _this.resizeEnd.next(event);
        }, this.resizeEndTimeout);
    };
    IgxColumnResizerDirective.prototype.onMousedown = function (event) {
        this.resizeStart.next(event);
        event.preventDefault();
        var elStyle = this.document.defaultView.getComputedStyle(this.element.nativeElement);
        this._left = Number.isNaN(parseInt(elStyle.left, 10)) ? 0 : parseInt(elStyle.left, 10);
    };
    IgxColumnResizerDirective.prototype.onMousemove = function (event) {
        this.resize.next(event);
        event.preventDefault();
    };
    IgxColumnResizerDirective.decorators = [
        { type: Directive, args: [{
                    selector: "[igxResizer]"
                },] },
    ];
    /** @nocollapse */
    IgxColumnResizerDirective.ctorParameters = function () { return [
        { type: ElementRef, },
        { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] },] },
    ]; };
    IgxColumnResizerDirective.propDecorators = {
        "restrictHResizeMin": [{ type: Input },],
        "restrictHResizeMax": [{ type: Input },],
        "resizeEndTimeout": [{ type: Input },],
        "resizeEnd": [{ type: Output },],
        "resizeStart": [{ type: Output },],
        "resize": [{ type: Output },],
        "onMouseup": [{ type: HostListener, args: ["document:mouseup", ["$event"],] },],
        "onMousedown": [{ type: HostListener, args: ["document:mousedown", ["$event"],] },],
        "onMousemove": [{ type: HostListener, args: ["document:mousemove", ["$event"],] },],
    };
    return IgxColumnResizerDirective;
}());
export { IgxColumnResizerDirective };
var IgxCellTemplateDirective = /** @class */ (function () {
    function IgxCellTemplateDirective(template) {
        this.template = template;
    }
    IgxCellTemplateDirective.decorators = [
        { type: Directive, args: [{
                    selector: "[igxCell]"
                },] },
    ];
    /** @nocollapse */
    IgxCellTemplateDirective.ctorParameters = function () { return [
        { type: TemplateRef, },
    ]; };
    return IgxCellTemplateDirective;
}());
export { IgxCellTemplateDirective };
var IgxCellHeaderTemplateDirective = /** @class */ (function () {
    function IgxCellHeaderTemplateDirective(template) {
        this.template = template;
    }
    IgxCellHeaderTemplateDirective.decorators = [
        { type: Directive, args: [{
                    selector: "[igxHeader]"
                },] },
    ];
    /** @nocollapse */
    IgxCellHeaderTemplateDirective.ctorParameters = function () { return [
        { type: TemplateRef, },
    ]; };
    return IgxCellHeaderTemplateDirective;
}());
export { IgxCellHeaderTemplateDirective };
var IgxCellFooterTemplateDirective = /** @class */ (function () {
    function IgxCellFooterTemplateDirective(template) {
        this.template = template;
    }
    IgxCellFooterTemplateDirective.decorators = [
        { type: Directive, args: [{
                    selector: "[igxFooter]"
                },] },
    ];
    /** @nocollapse */
    IgxCellFooterTemplateDirective.ctorParameters = function () { return [
        { type: TemplateRef, },
    ]; };
    return IgxCellFooterTemplateDirective;
}());
export { IgxCellFooterTemplateDirective };
var IgxCellEditorTemplateDirective = /** @class */ (function () {
    function IgxCellEditorTemplateDirective(template) {
        this.template = template;
    }
    IgxCellEditorTemplateDirective.decorators = [
        { type: Directive, args: [{
                    selector: "[igxCellEditor]"
                },] },
    ];
    /** @nocollapse */
    IgxCellEditorTemplateDirective.ctorParameters = function () { return [
        { type: TemplateRef, },
    ]; };
    return IgxCellEditorTemplateDirective;
}());
export { IgxCellEditorTemplateDirective };
/**
 * Decorates a setter or a method of a component implementing the IGridBus
 * interface triggering change detection in the parent grid when it is called.
 * If `markForCheck` is set to true it will also mark for check the instance
 * containing the setter/method.
 */
export function autoWire(markForCheck) {
    if (markForCheck === void 0) { markForCheck = false; }
    return function decorator(target, name, descriptor) {
        var old = descriptor.value || descriptor.set;
        var wrapped = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            var result = old.apply(this, args);
            if (markForCheck) {
                this.cdr.markForCheck();
            }
            this.gridAPI.notify(this.gridID);
            return result;
        };
        if (descriptor.set) {
            descriptor.set = wrapped;
        }
        else if (descriptor.value) {
            descriptor.value = wrapped;
        }
        else {
            throw Error("Can bind only to setter properties and methods");
        }
        return descriptor;
    };
}
//# sourceMappingURL=grid.common.js.map