import { EventEmitter } from "@angular/core";
/**
 * **Ignite UI for Angular Navbar** -
 * [Documentation](https://www.infragistics.com/products/ignite-ui-angular/angular/components/navbar.html)
 *
 * The Ignite UI Navbar is most commonly used to provide an app header with a hamburger menu and navigation
 * state such as a "Go Back" button. It also supports other actions represented by icons.
 *
 * Example:
 * ```html
 * <igx-navbar title="Sample App" actionButtonIcon="menu">
 *   <igx-icon name="search"></igx-icon>
 *   <igx-icon name="favorite"></igx-icon>
 *   <igx-icon name="more_vert"></igx-icon>
 * </igx-navbar>
 * ```
 */
export declare class IgxNavbarComponent {
    private static NEXT_ID;
    private isVisible;
    /**
     * The IgxNavbar action button visual state state
     * @type {boolean}
     */
    isActionButtonVisible: boolean;
    /**
     * The IgxNavbar action button actionButtonIcon
     * @type {string}
     */
    actionButtonIcon: string;
    /**
     * The IgxNavbar title
     * @type {string}
     */
    title: string;
    /**
     * The event that will be thrown when the action is executed,
     * provides reference to the IgxNavbar component as argument
     * @type {EventEmitter}
     */
    onAction: EventEmitter<IgxNavbarComponent>;
    titleId: string;
    _triggerAction(): void;
}
export declare class IgxNavbarModule {
}
