import { AnimationTransitionEvent, EventEmitter, NgZone } from "@angular/core";
/**
 * **Ignite UI for Angular Snackbar** -
 * [Documentation](https://www.infragistics.com/products/ignite-ui-angular/angular/components/snackbar.html)
 *
 * The Ignite UI Snack Bar provides feedback about an operation with a single-line message, which can
 * include a link to an action such as Undo.
 *
 * Example:
 * ```html
 * <button (click)="snackbar.show()">Send message</button>
 * <div>
 *   <igx-snackbar #snackbar message="Message sent">
 *   </igx-snackbar>
 * </div>
 * ```
 */
export declare class IgxSnackbarComponent {
    private zone;
    /**
     * The message that will be shown message by the IgxSnackbar component
     * @type {string}
     */
    message: string;
    /**
     * The IgxSnackbar component visual state state
     * @type {boolean}
     */
    isVisible: boolean;
    /**
     * Sets if the IgxSnackbar component will be hidden after shown
     * Default value is true
     * @type {number}
     */
    autoHide: boolean;
    /**
     * The duration of time span in ms which the IgxSnackbar component will be visible
     * after it is being shown.
     * Default value is 4000
     * @type {number}
     */
    displayTime: number;
    /**
     * The text of the IgxSnackbar component action
     * @type {string}
     */
    actionText?: string;
    /**
     * The event that will be thrown when the action is executed,
     * provides reference to the IgxSnackbar component as argument
     * @type {EventEmitter}
     */
    onAction: EventEmitter<IgxSnackbarComponent>;
    /**
     * The event that will be thrown when the snackbar animation starts
     * @type {EventEmitter<AnimationTransitionEvent>}
     */
    animationStarted: EventEmitter<AnimationTransitionEvent>;
    /**
     * The event that will be thrown when the snackbar animation ends
     * @type {EventEmitter<AnimationTransitionEvent>}
     */
    animationDone: EventEmitter<AnimationTransitionEvent>;
    private timeoutId;
    constructor(zone: NgZone);
    /**
     * Shows the IgxSnackbar component and hides it after some time span
     * if autoHide is enabled
     */
    show(): void;
    /**
     * Hides the IgxSnackbar component
     */
    hide(): void;
    triggerAction(): void;
    snackbarAnimationStarted(evt: AnimationTransitionEvent): void;
    snackbarAnimationDone(evt: AnimationTransitionEvent): void;
}
export declare class IgxSnackbarModule {
}
